# cody.py (Explorer Workshop)
# Copyright: 2024 Bradan Lane STUDIO
#
# Open Source License: MIT

'''
This CircuitPython program is a sample from the 'Hack the Badge' workshop

Implementation Notes
--------------------
**Hardware:**
    * one of the Explorer Badge designs

**Software and Dependencies:**
    * CircuitPython firmware (UF2): https://circuitpython.org
    * Adafruit CircuitPython Libraries: https://circuitpython.org/libraries

**Open Source Repository:**
    * GitLab: https://gitlab.com/bradanlane/exp_tutorial
    
'''

import board
import time
import digitalio
import pwmio


sound_enable = digitalio.DigitalInOut(board.SPEAKER_EN)
sound_enable.direction = digitalio.Direction.OUTPUT
sound_enable.value = False # we start with the amplifier OFF
sound_pwm = None
sound_enable.value = True

def tone_on(frequency:float=440.0):
    global sound_enable, sound_pwm
    ''' produce the given frequency (float) as a PWM signal '''
    print(f"Tone On ({frequency:f})")
    frequency = int(frequency)
    if sound_pwm is None:
        sound_pwm = pwmio.PWMOut(board.SPEAKER, frequency=frequency, variable_frequency=True)
        sound_pwm.duty_cycle = (65535 // 2) #0x8000
        sound_enable.value = True
    else:
        sound_pwm.frequency = frequency

def tone_off():
    global sound_enable, sound_pwm
    ''' stop producing sound '''
    if sound_pwm is not None:
        sound_pwm.deinit()
        sound_pwm = None
        sound_enable.value = False

def tone(frequency:float=440.0, duration:int=1.0):
    ''' produce the given sound for the given amount of time '''
    tone_on(frequency)
    time.sleep(duration)
    tone_off()


music_scale:list = [523.25, 587.33, 659.33, 698.46, 783.99, 880.00, 987.77, 1046.50, 1174.66]

# play each note without stopping between notes
for note in music_scale:
    tone_on(note)
    time.sleep(0.25)

tone_off()

counter:int = 0

try:
    while True:
        tone(music_scale[counter % len(music_scale)], 0.125)
        counter += 1

finally:
    # any cleanup code goes here
    pass
